# Data files required for aaindex package

* `aaindex1` - numerical amino acid indices for aaindex1 database.
* `aaindex2` - amino acid mutation matrices for aaindex2 database.
* `aaindex3` - amino acid pair-wise contact potentials for aaindex3 database.
* `aaindex1.json` - aaindex1 database in parsed json format.
* `aaindex_to_category.txt` - original unparsed text file matching each numerical index from the aaindex1 to its associated category.
* `aaindex_categories.txt` - parsed text file matching each numerical index from the aaindex1 to its associated category.
